@@ -10,20 +10,23 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.03';
-$DATE = '2003/07/11';
+$VERSION = '0.04';
+$DATE = '2003/07/26';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.03 2003/07/11), 'revised 0.02'],
-    'MANIFEST' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
-    'Makefile.PL' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
-    'README' => [qw(0.03 2003/07/11), 'generated, replaces 0.02'],
-    'lib/File/PM2File.pm' => [qw(1.11 2003/07/11), 'unchanged'],
-    't/File/PM2File.d' => [qw(0.02 2003/07/11), 'revised 0.01'],
-    't/File/PM2File.pm' => [qw(0.02 2003/07/11), 'revised 0.01'],
-    't/File/PM2File.t' => [qw(0.08 2003/07/11), 'revised 0.07'],
+    'lib/Docs/Site_SVD/File_PM2File.pm' => [qw(0.04 2003/07/26), 'revised 0.03'],
+    'MANIFEST' => [qw(0.04 2003/07/26), 'generated, replaces 0.03'],
+    'Makefile.PL' => [qw(0.04 2003/07/26), 'generated, replaces 0.03'],
+    'README' => [qw(0.04 2003/07/26), 'generated, replaces 0.03'],
+    'lib/File/PM2File.pm' => [qw(1.11 2003/07/26), 'revised 1.1'],
+    't/File/PM2File.d' => [qw(0.03 2003/07/26), 'revised 0.02'],
+    't/File/PM2File.pm' => [qw(0.01 2003/07/11), 'unchanged'],
+    't/File/PM2File.t' => [qw(0.09 2003/07/26), 'revised 0.08'],
+    'tlib/File/SubPM.pm' => [qw(1.1 2003/07/26), 'new'],
+    'tlib/File/Package.pm' => [qw(1.1 2003/07/26), 'new'],
+    'tlib/Test/Tech.pm' => [qw(1.1 2003/07/26), 'new'],
 
 );
 
@@ -50,11 +53,11 @@ use vars qw(%INVENTORY);
 
   File::PM2File - Convert PM specifications to file specifications
 
- Revision: B
+ Revision: C
 
- Version: 0.03
+ Version: 0.04
 
- Date: 2003/07/11
+ Date: 2003/07/26
 
  Prepared for: General Public 
 
@@ -88,7 +91,7 @@ to the file specification for the current site operating system.
 
 =head2 1.3 Document overview.
 
-This document releases File::PM2File version 0.03
+This document releases File::PM2File version 0.04
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -104,8 +107,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-PM2File-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.03
+   http://www.softwarediamonds/packages/File-PM2File-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.04
 
 
 Restrictions regarding duplication and license provisions
@@ -173,14 +176,17 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_PM2File.pm                            0.03    2003/07/11 revised 0.02
- MANIFEST                                                     0.03    2003/07/11 generated, replaces 0.02
- Makefile.PL                                                  0.03    2003/07/11 generated, replaces 0.02
- README                                                       0.03    2003/07/11 generated, replaces 0.02
- lib/File/PM2File.pm                                          1.11    2003/07/11 unchanged
- t/File/PM2File.d                                             0.02    2003/07/11 revised 0.01
- t/File/PM2File.pm                                            0.02    2003/07/11 revised 0.01
- t/File/PM2File.t                                             0.08    2003/07/11 revised 0.07
+ lib/Docs/Site_SVD/File_PM2File.pm                            0.04    2003/07/26 revised 0.03
+ MANIFEST                                                     0.04    2003/07/26 generated, replaces 0.03
+ Makefile.PL                                                  0.04    2003/07/26 generated, replaces 0.03
+ README                                                       0.04    2003/07/26 generated, replaces 0.03
+ lib/File/PM2File.pm                                          1.11    2003/07/26 revised 1.1
+ t/File/PM2File.d                                             0.03    2003/07/26 revised 0.02
+ t/File/PM2File.pm                                            0.01    2003/07/11 unchanged
+ t/File/PM2File.t                                             0.09    2003/07/26 revised 0.08
+ tlib/File/SubPM.pm                                           1.1     2003/07/26 new
+ tlib/File/Package.pm                                         1.1     2003/07/26 new
+ tlib/Test/Tech.pm                                            1.1     2003/07/26 new
 
 
 =head2 3.3 Changes
@@ -189,11 +195,11 @@ Changes are as follows:
 
 =over 4
 
-=item Test::TestUtil 0.01
+=item Test-TestUtil-0.01
 
 Originated
 
-=item Test::TestUtil 0.02
+=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -218,7 +224,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-=item Test::TestUtil 0.03
+=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -248,7 +254,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-=item Test::TestUtil 0.04
+=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -278,7 +284,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
   File::PM2File - Convert PM specifications to file specifications
 
 
- Revision: B
+ Revision: C
 
 [snip]
 
@@ -313,7 +319,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-=item File::FileUtil 0.01
+=item File-FileUtil-0.01
 
 =over 4
 
@@ -368,11 +374,11 @@ failure from CPAN testing whose is running on a different platform.
 
 =back
 
-=item File::FileUtil 0.02
+=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-=item File::FileUtil 0.03
+=item File-FileUtil-0.03
 
 =over 4
 
@@ -391,7 +397,7 @@ the directories in @INC
 
 =back
 
-=item File::PM2File 0.01
+=item File-PM2File-0.01
 
 Removed the methods for converting a
 program module specification to its
@@ -401,12 +407,24 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
-=item File::PM2File 0.02
+=item File-PM2File-0.02
 
 Changed prerequisite from "Test::STD::Scrub" to "Text::Scrub".
 This was a change to make the name more descriptive of the contents
 of the program module.
 
+=item File-PM2File-0.03
+
+Added 1 to the end of File::PM2File
+
+=item File-PM2File-0.04
+
+Added SelfLoader to File::PM2File
+
+Change test so that test support files resides in distribution
+directory tlib. Test support files not longer need be in the
+lib directory. The test support files in tlib will vanish after
+the installtion.
 
 =back
 
@@ -414,15 +432,6 @@ of the program module.
 
 This installation requires that the installation site
 has the Perl programming language installed.
-Installation sites running Microsoft Operating systems require
-the installation of Unix utilities. 
-An excellent, highly recommended Unix utilities for Microsoft
-operating systems is unxutils by Karl M. Syring.
-A copy is available at the following web sites:
-
- http://unxutils.sourceforge.net
- http://packages.SoftwareDiamnds.com
-
 There are no other additional requirements or tailoring needed of 
 configurations files, adaptation data or other software needed for this
 installation particular to any installation site.
@@ -450,17 +459,13 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-PM2File-0.03
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.03
+   http://www.softwarediamonds/packages/File-PM2File-0.04
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-PM2File-0.04
 
 
 =item Prerequistes.
 
- 'File::SmartNL' => '0',
- 'File::Package' => '0',
- 'File::TestPath' => '0',
- 'Text::Scrub' => '0',
- 'Test::Tech' => '1.08',
+ None.
 
 
 =item Security, privacy, or safety precautions.
@@ -542,7 +547,7 @@ Plain Old Documentation
 
 =head1 2.0 SEE ALSO
 
-
+L<File::File2PM|File::File2PM>
 
 =for html
 <hr>
@@ -569,11 +574,11 @@ __DATA__
 DISTNAME: File-PM2File^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.03^
+VERSION : 0.04^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.02^
-REVISION: B^
+PREVIOUS_RELEASE: 0.03^
+REVISION: C^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 
@@ -603,15 +608,12 @@ CHANGE2CURRENT:  ^
 AUTO_REVISE: 
 lib/File/PM2File.pm
 t/File/PM2File.*
+lib/File/SubPM.pm => tlib/File/SubPM.pm
+lib/File/Package.pm => tlib/File/Package.pm
+lib/Test/Tech.pm => tlib/Test/Tech.pm
 ^
 
-PREREQ_PM:
-'File::SmartNL' => '0',
-'File::Package' => '0',
-'File::TestPath' => '0',
-'Text::Scrub' => '0',
-'Test::Tech' => '1.08',
-^
+PREREQ_PM:  ^
 
 TESTS: t/File/PM2File.t^
 
@@ -621,11 +623,11 @@ Changes are as follows:
 
 \=over 4
 
-\=item Test::TestUtil 0.01
+\=item Test-TestUtil-0.01
 
 Originated
 
-\=item Test::TestUtil 0.02
+\=item Test-TestUtil-0.02
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -650,7 +652,7 @@ that changes file specifications from one operating system
 to another operating system.
 This method has been in service unchanged for some time.
 
-\=item Test::TestUtil 0.03
+\=item Test-TestUtil-0.03
 
 Correct failure from Josts Smokehouse" <Jost.Krieger+smokeback@ruhr-uni-bochum.de>
 test run
@@ -680,7 +682,7 @@ test script for this
 feature, and added a discusssion of this feature in
 POD discription for I<format_hash_table>
 
-\=item Test::TestUtil 0.04
+\=item Test-TestUtil-0.04
 
 item our old friend visits again - DOS and UNIX text file incompatibility
 
@@ -745,7 +747,7 @@ instead of using the raw file handle.
 The I<fin> method takes any \015\012 combination and changes it into the 
 logical Perl new line, I<"\n">, for the current operating system.
 
-\=item File::FileUtil 0.01
+\=item File-FileUtil-0.01
 
 \=over 4
 
@@ -800,11 +802,11 @@ failure from CPAN testing whose is running on a different platform.
 
 \=back
 
-\=item File::FileUtil 0.02
+\=item File-FileUtil-0.02
 
 Added the method I<hex_dump>.
 
-\=item File::FileUtil 0.03
+\=item File-FileUtil-0.03
 
 \=over 4
 
@@ -823,7 +825,7 @@ the directories in @INC
 
 \=back
 
-\=item File::PM2File 0.01
+\=item File-PM2File-0.01
 
 Removed the methods for converting a
 program module specification to its
@@ -833,12 +835,24 @@ absolute file from the
 The module name is now more descriptive
 of the routines in the module.
 
-\=item File::PM2File 0.02
+\=item File-PM2File-0.02
 
 Changed prerequisite from "Test::STD::Scrub" to "Text::Scrub".
 This was a change to make the name more descriptive of the contents
 of the program module.
 
+\=item File-PM2File-0.03
+
+Added 1 to the end of File::PM2File
+
+\=item File-PM2File-0.04
+
+Added SelfLoader to File::PM2File
+
+Change test so that test support files resides in distribution
+directory tlib. Test support files not longer need be in the
+lib directory. The test support files in tlib will vanish after
+the installtion.
 
 \=back
 
@@ -979,7 +993,7 @@ Plain Old Documentation
 \=back
 ^
 
-SEE_ALSO:  ^
+SEE_ALSO: L<File::File2PM|File::File2PM>^
 
 HTML:
 <hr>
